From 59df1cb354364b0e2c2e9ec48b948a439b7d164b Mon Sep 17 00:00:00 2001
From: moparisthebest Represents a class ID (16 bytes). Unlike other little-endian
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/ClipboardData.java b/src/main/java/com/moparisthebest/poi/hpsf/ClipboardData.java
index 42ce724a9..8dfa765b1 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/ClipboardData.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/ClipboardData.java
@@ -14,15 +14,15 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.IOException;
import java.io.OutputStream;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
@Internal
class ClipboardData
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/CodePageString.java b/src/main/java/com/moparisthebest/poi/hpsf/CodePageString.java
index 8eb8987b3..2c356eac3 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/CodePageString.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/CodePageString.java
@@ -14,18 +14,18 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.IOException;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
-import org.apache.poi.util.CodePageUtil;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
-import org.apache.poi.util.StringUtil;
+import com.moparisthebest.poi.util.CodePageUtil;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
+import com.moparisthebest.poi.util.StringUtil;
@Internal
class CodePageString
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Currency.java b/src/main/java/com/moparisthebest/poi/hpsf/Currency.java
index 8928a56a0..3a077b4b7 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Currency.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Currency.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class Currency
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/CustomProperty.java b/src/main/java/com/moparisthebest/poi/hpsf/CustomProperty.java
index 83511655a..0815512b1 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/CustomProperty.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/CustomProperty.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This class represents custom properties in the document summary
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Date.java b/src/main/java/com/moparisthebest/poi/hpsf/Date.java
index 237420fcc..a1e52f1cc 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Date.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Date.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class Date
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Decimal.java b/src/main/java/com/moparisthebest/poi/hpsf/Decimal.java
index d8c404c31..fb7e34472 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Decimal.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Decimal.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class Decimal
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/DocumentSummaryInformation.java b/src/main/java/com/moparisthebest/poi/hpsf/DocumentSummaryInformation.java
index fac3ffb7e..aa2e4b586 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/DocumentSummaryInformation.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/DocumentSummaryInformation.java
@@ -15,15 +15,15 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
-import org.apache.poi.hpsf.wellknown.PropertyIDMap;
-import org.apache.poi.hpsf.wellknown.SectionIDMap;
-import org.apache.poi.util.CodePageUtil;
+import com.moparisthebest.poi.hpsf.wellknown.PropertyIDMap;
+import com.moparisthebest.poi.hpsf.wellknown.SectionIDMap;
+import com.moparisthebest.poi.util.CodePageUtil;
/**
* Convenience class representing a DocumentSummary Information stream in a
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Filetime.java b/src/main/java/com/moparisthebest/poi/hpsf/Filetime.java
index 84a58bb1d..451383284 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Filetime.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Filetime.java
@@ -14,12 +14,12 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.IOException;
import java.io.OutputStream;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.LittleEndian;
class Filetime
{
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/GUID.java b/src/main/java/com/moparisthebest/poi/hpsf/GUID.java
index 4bbd7f341..c9b63efde 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/GUID.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/GUID.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class GUID
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/HPSFException.java b/src/main/java/com/moparisthebest/poi/hpsf/HPSFException.java
index abc3b8d9f..1921d4037 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/HPSFException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/HPSFException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is the superclass of all other checked exceptions thrown
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/HPSFPropertiesOnlyDocument.java b/src/main/java/com/moparisthebest/poi/hpsf/HPSFPropertiesOnlyDocument.java
index 1097b71e4..1e062a747 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/HPSFPropertiesOnlyDocument.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/HPSFPropertiesOnlyDocument.java
@@ -14,7 +14,7 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.File;
import java.io.IOException;
@@ -22,12 +22,12 @@ import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
-import org.apache.poi.POIDocument;
-import org.apache.poi.poifs.filesystem.EntryUtils;
-import org.apache.poi.poifs.filesystem.FilteringDirectoryNode;
-import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
-import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
-import org.apache.poi.poifs.filesystem.POIFSFileSystem;
+import com.moparisthebest.poi.POIDocument;
+import com.moparisthebest.poi.poifs.filesystem.EntryUtils;
+import com.moparisthebest.poi.poifs.filesystem.FilteringDirectoryNode;
+import com.moparisthebest.poi.poifs.filesystem.NPOIFSFileSystem;
+import com.moparisthebest.poi.poifs.filesystem.OPOIFSFileSystem;
+import com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem;
/**
* A version of {@link POIDocument} which allows access to the
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/HPSFRuntimeException.java b/src/main/java/com/moparisthebest/poi/hpsf/HPSFRuntimeException.java
index 984a316fc..c71028d48 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/HPSFRuntimeException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/HPSFRuntimeException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/IllegalPropertySetDataException.java b/src/main/java/com/moparisthebest/poi/hpsf/IllegalPropertySetDataException.java
index 3217af958..d60223428 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/IllegalPropertySetDataException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/IllegalPropertySetDataException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown when there is an illegal value set in a
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/IllegalVariantTypeException.java b/src/main/java/com/moparisthebest/poi/hpsf/IllegalVariantTypeException.java
index b71ff4703..861210921 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/IllegalVariantTypeException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/IllegalVariantTypeException.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.HexDump;
/**
* This exception is thrown if HPSF encounters a variant type that is illegal
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/IndirectPropertyName.java b/src/main/java/com/moparisthebest/poi/hpsf/IndirectPropertyName.java
index fc09ca6e8..559788e72 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/IndirectPropertyName.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/IndirectPropertyName.java
@@ -14,9 +14,9 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
+import com.moparisthebest.poi.util.Internal;
@Internal
class IndirectPropertyName
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/MarkUnsupportedException.java b/src/main/java/com/moparisthebest/poi/hpsf/MarkUnsupportedException.java
index 450c892ab..9b6828b3c 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/MarkUnsupportedException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/MarkUnsupportedException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown if an {@link java.io.InputStream} does
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/MissingSectionException.java b/src/main/java/com/moparisthebest/poi/hpsf/MissingSectionException.java
index f3e81cad2..65e50510e 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/MissingSectionException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/MissingSectionException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown if one of the {@link PropertySet}'s
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/MutableProperty.java b/src/main/java/com/moparisthebest/poi/hpsf/MutableProperty.java
index 10d86be04..1cec0bdd5 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/MutableProperty.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/MutableProperty.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Removal;
+import com.moparisthebest.poi.util.Removal;
/**
* Adds writing capability to the {@link Property} class.
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/MutableSection.java b/src/main/java/com/moparisthebest/poi/hpsf/MutableSection.java
index c5f0d6e0c..a374c841c 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/MutableSection.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/MutableSection.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.UnsupportedEncodingException;
-import org.apache.poi.util.Removal;
+import com.moparisthebest.poi.util.Removal;
/**
* Adds writing capability to the {@link Section} class. This exception is thrown if a format error in a property set stream is
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/NoSingleSectionException.java b/src/main/java/com/moparisthebest/poi/hpsf/NoSingleSectionException.java
index 2309fe561..062f99eb3 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/NoSingleSectionException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/NoSingleSectionException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown if one of the {@link PropertySet}'s
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Property.java b/src/main/java/com/moparisthebest/poi/hpsf/Property.java
index 8c81f0b2f..4f14c9214 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Property.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Property.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.IOException;
import java.io.OutputStream;
@@ -25,11 +25,11 @@ import java.util.Arrays;
import java.util.LinkedHashMap;
import java.util.Map;
-import org.apache.poi.util.CodePageUtil;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
+import com.moparisthebest.poi.util.CodePageUtil;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
/**
* A property in a {@link Section} of a {@link PropertySet}.
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/PropertySet.java b/src/main/java/com/moparisthebest/poi/hpsf/PropertySet.java
index 508ede25c..9bf58c040 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/PropertySet.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/PropertySet.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
@@ -29,15 +29,15 @@ import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
-import org.apache.poi.EmptyFileException;
-import org.apache.poi.hpsf.wellknown.PropertyIDMap;
-import org.apache.poi.hpsf.wellknown.SectionIDMap;
-import org.apache.poi.poifs.filesystem.DirectoryEntry;
-import org.apache.poi.poifs.filesystem.Entry;
-import org.apache.poi.util.IOUtils;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.LittleEndianConsts;
-import org.apache.poi.util.NotImplemented;
+import com.moparisthebest.poi.EmptyFileException;
+import com.moparisthebest.poi.hpsf.wellknown.PropertyIDMap;
+import com.moparisthebest.poi.hpsf.wellknown.SectionIDMap;
+import com.moparisthebest.poi.poifs.filesystem.DirectoryEntry;
+import com.moparisthebest.poi.poifs.filesystem.Entry;
+import com.moparisthebest.poi.util.IOUtils;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.LittleEndianConsts;
+import com.moparisthebest.poi.util.NotImplemented;
/**
* Represents a property set in the Horrible Property Set Format
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/PropertySetFactory.java b/src/main/java/com/moparisthebest/poi/hpsf/PropertySetFactory.java
index db0a73d13..6e24d1a1b 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/PropertySetFactory.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/PropertySetFactory.java
@@ -15,16 +15,16 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
-import org.apache.poi.poifs.filesystem.DirectoryEntry;
-import org.apache.poi.poifs.filesystem.DocumentEntry;
-import org.apache.poi.poifs.filesystem.DocumentInputStream;
+import com.moparisthebest.poi.poifs.filesystem.DirectoryEntry;
+import com.moparisthebest.poi.poifs.filesystem.DocumentEntry;
+import com.moparisthebest.poi.poifs.filesystem.DocumentInputStream;
/**
* Factory class to create instances of {@link SummaryInformation},
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/ReadingNotSupportedException.java b/src/main/java/com/moparisthebest/poi/hpsf/ReadingNotSupportedException.java
index cb16058a7..9bcf667a3 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/ReadingNotSupportedException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/ReadingNotSupportedException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown when HPSF tries to read a (yet) unsupported
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Section.java b/src/main/java/com/moparisthebest/poi/hpsf/Section.java
index 4e5ab23be..314eeee51 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Section.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Section.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
@@ -25,10 +25,10 @@ import java.util.Date;
import java.util.Map;
import java.util.TreeMap;
-import org.apache.poi.hpsf.wellknown.PropertyIDMap;
-import org.apache.poi.hpsf.wellknown.SectionIDMap;
-import org.apache.poi.util.CodePageUtil;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.hpsf.wellknown.PropertyIDMap;
+import com.moparisthebest.poi.hpsf.wellknown.SectionIDMap;
+import com.moparisthebest.poi.util.CodePageUtil;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* Represents a section in a {@link PropertySet}.
@@ -123,7 +123,7 @@ public class Section {
* Returns the format ID. The format ID is the "type" of the
* section. For example, if the format ID of the first {@link
* Section} contains the bytes specified by
- * {@code org.apache.poi.hpsf.wellknown.SectionIDMap.SUMMARY_INFORMATION_ID}
+ * {@code com.moparisthebest.poi.hpsf.wellknown.SectionIDMap.SUMMARY_INFORMATION_ID}
* the section (and thus the property set) is a SummaryInformation.
*
* @return The format ID
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/SpecialPropertySet.java b/src/main/java/com/moparisthebest/poi/hpsf/SpecialPropertySet.java
index 843d681eb..a4dd0238a 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/SpecialPropertySet.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/SpecialPropertySet.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Removal;
+import com.moparisthebest.poi.util.Removal;
/**
* Interface for the convenience classes {@link SummaryInformation}
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/SummaryInformation.java b/src/main/java/com/moparisthebest/poi/hpsf/SummaryInformation.java
index e2ea8568b..da7a7f977 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/SummaryInformation.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/SummaryInformation.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.util.Date;
-import org.apache.poi.hpsf.wellknown.PropertyIDMap;
-import org.apache.poi.hpsf.wellknown.SectionIDMap;
+import com.moparisthebest.poi.hpsf.wellknown.PropertyIDMap;
+import com.moparisthebest.poi.hpsf.wellknown.SectionIDMap;
/**
* Convenience class representing a Summary Information stream in a
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Thumbnail.java b/src/main/java/com/moparisthebest/poi/hpsf/Thumbnail.java
index a1faf3d08..59aae012c 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Thumbnail.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Thumbnail.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* Class to manipulate data in the Clipboard Variant ({@link
* Variant#VT_CF VT_CF}) format. Class for writing little-endian data and more. This exception is thrown if a certain type of property set is
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/UnicodeString.java b/src/main/java/com/moparisthebest/poi/hpsf/UnicodeString.java
index 0d3cdbf29..826fbe46f 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/UnicodeString.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/UnicodeString.java
@@ -14,13 +14,13 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
-import org.apache.poi.util.StringUtil;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
+import com.moparisthebest.poi.util.StringUtil;
@Internal
class UnicodeString {
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/UnsupportedVariantTypeException.java b/src/main/java/com/moparisthebest/poi/hpsf/UnsupportedVariantTypeException.java
index 12afdcb4c..1c5141378 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/UnsupportedVariantTypeException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/UnsupportedVariantTypeException.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.HexDump;
/**
* This exception is thrown if HPSF encounters a variant type that isn't
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Util.java b/src/main/java/com/moparisthebest/poi/hpsf/Util.java
index d8ab7315d..0e0b9d238 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Util.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Util.java
@@ -15,15 +15,15 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Date;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.SuppressForbidden;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.SuppressForbidden;
/**
* Provides various static utility methods.
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/VariantTypeException.java b/src/main/java/com/moparisthebest/poi/hpsf/VariantTypeException.java
index c2d2e8f66..06cdce717 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/VariantTypeException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/VariantTypeException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown if HPSF encounters a problem with a variant type.
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Vector.java b/src/main/java/com/moparisthebest/poi/hpsf/Vector.java
index a1ddb0812..ecb3d5a16 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Vector.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Vector.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* Holder for vector-type properties
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/VersionedStream.java b/src/main/java/com/moparisthebest/poi/hpsf/VersionedStream.java
index c3c066e4f..0a055530b 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/VersionedStream.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/VersionedStream.java
@@ -16,9 +16,9 @@
* limitations under the License.
* ====================================================================
*/
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
+import com.moparisthebest.poi.util.Internal;
@Internal
class VersionedStream
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/WritingNotSupportedException.java b/src/main/java/com/moparisthebest/poi/hpsf/WritingNotSupportedException.java
index d409999f7..7dcc3a090 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/WritingNotSupportedException.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/WritingNotSupportedException.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
/**
* This exception is thrown when trying to write a (yet) unsupported variant
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/extractor/HPSFPropertiesExtractor.java b/src/main/java/com/moparisthebest/poi/hpsf/extractor/HPSFPropertiesExtractor.java
index b84b169d3..d657a024d 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/extractor/HPSFPropertiesExtractor.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/extractor/HPSFPropertiesExtractor.java
@@ -15,23 +15,23 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf.extractor;
+package com.moparisthebest.poi.hpsf.extractor;
import java.io.File;
import java.io.IOException;
-import org.apache.poi.POIDocument;
-import org.apache.poi.POIOLE2TextExtractor;
-import org.apache.poi.POITextExtractor;
-import org.apache.poi.hpsf.DocumentSummaryInformation;
-import org.apache.poi.hpsf.HPSFPropertiesOnlyDocument;
-import org.apache.poi.hpsf.Property;
-import org.apache.poi.hpsf.PropertySet;
-import org.apache.poi.hpsf.SpecialPropertySet;
-import org.apache.poi.hpsf.SummaryInformation;
-import org.apache.poi.hpsf.wellknown.PropertyIDMap;
-import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
-import org.apache.poi.poifs.filesystem.POIFSFileSystem;
+import com.moparisthebest.poi.POIDocument;
+import com.moparisthebest.poi.POIOLE2TextExtractor;
+import com.moparisthebest.poi.POITextExtractor;
+import com.moparisthebest.poi.hpsf.DocumentSummaryInformation;
+import com.moparisthebest.poi.hpsf.HPSFPropertiesOnlyDocument;
+import com.moparisthebest.poi.hpsf.Property;
+import com.moparisthebest.poi.hpsf.PropertySet;
+import com.moparisthebest.poi.hpsf.SpecialPropertySet;
+import com.moparisthebest.poi.hpsf.SummaryInformation;
+import com.moparisthebest.poi.hpsf.wellknown.PropertyIDMap;
+import com.moparisthebest.poi.poifs.filesystem.NPOIFSFileSystem;
+import com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem;
/**
* Extracts all of the HPSF properties, both
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/package.html b/src/main/java/com/moparisthebest/poi/hpsf/package.html
index f5cfe430c..cf3a80e6f 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/package.html
+++ b/src/main/java/com/moparisthebest/poi/hpsf/package.html
@@ -35,63 +35,63 @@
In order to extract the properties from a POI filesystem, a property set
stream's contents must be parsed into a {@link
- org.apache.poi.hpsf.PropertySet} instance. Its subclasses {@link
- org.apache.poi.hpsf.SummaryInformation} and {@link
- org.apache.poi.hpsf.DocumentSummaryInformation} deal with the well-known
+ com.moparisthebest.poi.hpsf.PropertySet} instance. Its subclasses {@link
+ com.moparisthebest.poi.hpsf.SummaryInformation} and {@link
+ com.moparisthebest.poi.hpsf.DocumentSummaryInformation} deal with the well-known
property set streams \005SummaryInformation and
\005DocumentSummaryInformation. (However, the streams' names are
irrelevant. What counts is the property set's first section's format ID -
see below.) The factory method {@link org.apache.poi.hpsf.PropertySetFactory#create}
- creates a {@link org.apache.poi.hpsf.PropertySet} instance. This method
+ The factory method {@link com.moparisthebest.poi.hpsf.PropertySetFactory#create}
+ creates a {@link com.moparisthebest.poi.hpsf.PropertySet} instance. This method
always returns the most specific property set: If it
identifies the stream data as a Summary Information or as a Document
Summary Information it returns an instance of the corresponding class, else
- the general {@link org.apache.poi.hpsf.PropertySet}.EscherBlipRecord
and stores
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherBitmapBlip.java b/src/main/java/com/moparisthebest/poi/ddf/EscherBitmapBlip.java
index 84a4824b2..e6540ef73 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherBitmapBlip.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherBitmapBlip.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
public class EscherBitmapBlip extends EscherBlipRecord {
public static final short RECORD_ID_JPEG = (short) 0xF018 + 5;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherBlipRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherBlipRecord.java
index ccacc7b9c..d673d0430 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherBlipRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherBlipRecord.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
public class EscherBlipRecord extends EscherRecord {
public static final short RECORD_ID_START = (short) 0xF018;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherBoolProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherBoolProperty.java
index ce36bc665..f88f53e45 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherBoolProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherBoolProperty.java
@@ -16,9 +16,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.HexDump;
/**
* Represents a boolean property. The actual utility of this property is in doubt because many
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherChildAnchorRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherChildAnchorRecord.java
index 1fb16444f..b3f2c5585 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherChildAnchorRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherChildAnchorRecord.java
@@ -16,10 +16,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* The escher child achor record is used to specify the position of a shape under an
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherClientAnchorRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherClientAnchorRecord.java
index bb1cf66ee..98ed51990 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherClientAnchorRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherClientAnchorRecord.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* The escher client anchor specifies which rows and cells the shape is bound to as well as
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherClientDataRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherClientDataRecord.java
index 749007cfe..4deab373a 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherClientDataRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherClientDataRecord.java
@@ -16,10 +16,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* The EscherClientDataRecord is used to store client specific data about the position of a
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherColorRef.java b/src/main/java/com/moparisthebest/poi/ddf/EscherColorRef.java
index cbd62e17b..296c1fe94 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherColorRef.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherColorRef.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.BitField;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.BitField;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* An OfficeArtCOLORREF structure entry which also handles color extension opid data
@@ -267,7 +267,7 @@ public class EscherColorRef {
/**
* @return index of the scheme color or -1 if {@link #hasSchemeIndexFlag()} is {@code false}
*
- * @see org.apache.poi.hslf.record.ColorSchemeAtom#getColor(int)
+ * @see com.moparisthebest.poi.hslf.record.ColorSchemeAtom#getColor(int)
*/
public int getSchemeIndex() {
if (!hasSchemeIndexFlag()) return -1;
@@ -284,7 +284,7 @@ public class EscherColorRef {
/**
* @return index of system color table or -1 if {@link #hasSysIndexFlag()} is {@code false}
*
- * @see org.apache.poi.sl.usermodel.PresetColor
+ * @see com.moparisthebest.poi.sl.usermodel.PresetColor
*/
public int getSysIndex() {
return (hasSysIndexFlag()) ? getIndex() : -1;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherComplexProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherComplexProperty.java
index 06bdaf5c3..1920716fc 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherComplexProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherComplexProperty.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.util.Arrays;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* A complex property differs from a simple property in that the data can not fit inside a 32 bit
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherContainerRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherContainerRecord.java
index e570084b2..975b18730 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherContainerRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherContainerRecord.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.io.PrintWriter;
import java.util.ArrayList;
@@ -23,11 +23,11 @@ import java.util.Collections;
import java.util.Iterator;
import java.util.List;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
-import org.apache.poi.util.Removal;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
+import com.moparisthebest.poi.util.Removal;
/**
* Escher container records store other escher records as children.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherDgRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherDgRecord.java
index 7de76e241..0f1813b8f 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherDgRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherDgRecord.java
@@ -16,10 +16,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* This record simply holds the number of shapes in the drawing group and the
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherDggRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherDggRecord.java
index 5b1b8b744..a21dcad47 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherDggRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherDggRecord.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.RecordFormatException;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.RecordFormatException;
import java.util.*;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherDump.java b/src/main/java/com/moparisthebest/poi/ddf/EscherDump.java
index 45905c936..6600ca3d5 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherDump.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherDump.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.HexRead;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.HexRead;
+import com.moparisthebest.poi.util.LittleEndian;
import java.io.ByteArrayInputStream;
import java.io.IOException;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherMetafileBlip.java b/src/main/java/com/moparisthebest/poi/ddf/EscherMetafileBlip.java
index ffd740cde..081bb452f 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherMetafileBlip.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherMetafileBlip.java
@@ -15,13 +15,13 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
-import org.apache.poi.hssf.usermodel.HSSFPictureData;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
+import com.moparisthebest.poi.hssf.usermodel.HSSFPictureData;
import java.awt.Dimension;
import java.awt.Rectangle;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherOptRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherOptRecord.java
index 94b226b3a..c83d1c294 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherOptRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherOptRecord.java
@@ -14,9 +14,9 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.Internal;
+import com.moparisthebest.poi.util.Internal;
/**
* The opt record is used to store property values for a shape. It is the key to
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherPictBlip.java b/src/main/java/com/moparisthebest/poi/ddf/EscherPictBlip.java
index cbd5fe20a..ecff35d1c 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherPictBlip.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherPictBlip.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
import java.awt.Dimension;
import java.awt.Rectangle;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherProperties.java b/src/main/java/com/moparisthebest/poi/ddf/EscherProperties.java
index 096a20c57..57b070c87 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherProperties.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherProperties.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.util.HashMap;
import java.util.Map;
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherProperty.java
index d883fe0d0..0768034bf 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherProperty.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* This is the abstract base class for all escher properties.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyFactory.java b/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyFactory.java
index 642c3056d..28f3f9d0d 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyFactory.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyFactory.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.util.ArrayList;
import java.util.List;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* Generates a property given a reference into the byte array storing that property.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyMetaData.java b/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyMetaData.java
index b38e52df3..aa2e789d6 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyMetaData.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherPropertyMetaData.java
@@ -16,7 +16,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* This class stores the type and description of an escher property.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherRGBProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherRGBProperty.java
index 38b77f4a9..4dff463eb 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherRGBProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherRGBProperty.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.HexDump;
/**
* A color property.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherRecord.java
index 65926a8c1..bf141bd3a 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherRecord.java
@@ -16,17 +16,17 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.List;
-import org.apache.poi.util.BitField;
-import org.apache.poi.util.BitFieldFactory;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.BitField;
+import com.moparisthebest.poi.util.BitFieldFactory;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* The base abstract record from which all escher records are defined. Subclasses will need
@@ -53,7 +53,7 @@ public abstract class EscherRecord implements Cloneable {
* @param f the escher record factory
* @return The number of bytes written.
*
- * @see #fillFields(byte[], int, org.apache.poi.ddf.EscherRecordFactory)
+ * @see #fillFields(byte[], int, com.moparisthebest.poi.ddf.EscherRecordFactory)
*/
protected int fillFields( byte[] data, EscherRecordFactory f )
{
@@ -159,7 +159,7 @@ public abstract class EscherRecord implements Cloneable {
* @param data the data array to serialize to.
* @return The number of bytes written.
*
- * @see #serialize(int, byte[], org.apache.poi.ddf.EscherSerializationListener)
+ * @see #serialize(int, byte[], com.moparisthebest.poi.ddf.EscherSerializationListener)
*/
public int serialize( int offset, byte[] data)
{
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherRecordFactory.java b/src/main/java/com/moparisthebest/poi/ddf/EscherRecordFactory.java
index 401bbd08c..c979a0735 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherRecordFactory.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherRecordFactory.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* The escher record factory interface allows for the creation of escher
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherSerializationListener.java b/src/main/java/com/moparisthebest/poi/ddf/EscherSerializationListener.java
index dcc5eeeb8..16f8c5b46 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherSerializationListener.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherSerializationListener.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* Interface for listening to escher serialization events.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherShapePathProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherShapePathProperty.java
index f495f2639..3f23f0e44 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherShapePathProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherShapePathProperty.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* Defines the constants for the various possible shape paths.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherSimpleProperty.java b/src/main/java/com/moparisthebest/poi/ddf/EscherSimpleProperty.java
index 57b1d9df3..cc2fc992a 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherSimpleProperty.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherSimpleProperty.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
/**
* A simple property is of fixed length and as a property number in addition
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherSpRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherSpRecord.java
index 3fec761ab..f562525b2 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherSpRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherSpRecord.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* Together the the EscherOptRecord this record defines some of the basic
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherSpgrRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherSpgrRecord.java
index a4d30b39a..054d74f2f 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherSpgrRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherSpgrRecord.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.RecordFormatException;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.RecordFormatException;
/**
* The spgr record defines information about a shape group. Groups in escher
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherSplitMenuColorsRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherSplitMenuColorsRecord.java
index 3467d0a44..bed1f9e53 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherSplitMenuColorsRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherSplitMenuColorsRecord.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.RecordFormatException;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.RecordFormatException;
/**
* A list of the most recently used colours for the drawings contained in
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherTertiaryOptRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherTertiaryOptRecord.java
index 618294211..abb0161fb 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherTertiaryOptRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherTertiaryOptRecord.java
@@ -14,7 +14,7 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* "The OfficeArtTertiaryFOPT record specifies a table of OfficeArtRGFOPTE properties, as defined in section 2.3.1."
diff --git a/src/main/java/com/moparisthebest/poi/ddf/EscherTextboxRecord.java b/src/main/java/com/moparisthebest/poi/ddf/EscherTextboxRecord.java
index 779808000..a3e877136 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/EscherTextboxRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/EscherTextboxRecord.java
@@ -15,11 +15,11 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.util.RecordFormatException;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.RecordFormatException;
/**
* Holds data from the parent application. Most commonly used to store
diff --git a/src/main/java/com/moparisthebest/poi/ddf/NullEscherSerializationListener.java b/src/main/java/com/moparisthebest/poi/ddf/NullEscherSerializationListener.java
index 28a8c94a6..0ab335709 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/NullEscherSerializationListener.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/NullEscherSerializationListener.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
/**
* Ignores all serialization events.
diff --git a/src/main/java/com/moparisthebest/poi/ddf/UnknownEscherRecord.java b/src/main/java/com/moparisthebest/poi/ddf/UnknownEscherRecord.java
index 6f871528a..606b71f5e 100644
--- a/src/main/java/com/moparisthebest/poi/ddf/UnknownEscherRecord.java
+++ b/src/main/java/com/moparisthebest/poi/ddf/UnknownEscherRecord.java
@@ -15,14 +15,14 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.ddf;
+package com.moparisthebest.poi.ddf;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.LittleEndian;
/**
* This record is used whenever a escher record is encountered that
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Array.java b/src/main/java/com/moparisthebest/poi/hpsf/Array.java
index 8850ab9cd..08c5bdf19 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Array.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Array.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class Array
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/Blob.java b/src/main/java/com/moparisthebest/poi/hpsf/Blob.java
index 547e2392b..4068560ed 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/Blob.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/Blob.java
@@ -14,10 +14,10 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
-import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import com.moparisthebest.poi.util.Internal;
+import com.moparisthebest.poi.util.LittleEndian;
@Internal
class Blob
diff --git a/src/main/java/com/moparisthebest/poi/hpsf/ClassID.java b/src/main/java/com/moparisthebest/poi/hpsf/ClassID.java
index 0dacf8013..d7c4c646f 100644
--- a/src/main/java/com/moparisthebest/poi/hpsf/ClassID.java
+++ b/src/main/java/com/moparisthebest/poi/hpsf/ClassID.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hpsf;
+package com.moparisthebest.poi.hpsf;
import java.util.Arrays;
-import org.apache.poi.util.HexDump;
-import org.apache.poi.util.StringUtil;
+import com.moparisthebest.poi.util.HexDump;
+import com.moparisthebest.poi.util.StringUtil;
/**
*
A {@link org.apache.poi.hpsf.PropertySet} contains a list of {@link - org.apache.poi.hpsf.Section}s which can be retrieved with {@link - org.apache.poi.hpsf.PropertySet#getSections}. Each {@link - org.apache.poi.hpsf.Section} contains a {@link - org.apache.poi.hpsf.Property} array which can be retrieved with {@link - org.apache.poi.hpsf.Section#getProperties}. Since the vast majority of - {@link org.apache.poi.hpsf.PropertySet}s contains only a single {@link - org.apache.poi.hpsf.Section}, the convenience method {@link - org.apache.poi.hpsf.PropertySet#getProperties} returns the properties of a - {@link org.apache.poi.hpsf.PropertySet}'s {@link - org.apache.poi.hpsf.Section} (throwing a {@link - org.apache.poi.hpsf.NoSingleSectionException} if the {@link - org.apache.poi.hpsf.PropertySet} contains more (or less) than exactly one - {@link org.apache.poi.hpsf.Section}).
+A {@link com.moparisthebest.poi.hpsf.PropertySet} contains a list of {@link + com.moparisthebest.poi.hpsf.Section}s which can be retrieved with {@link + com.moparisthebest.poi.hpsf.PropertySet#getSections}. Each {@link + com.moparisthebest.poi.hpsf.Section} contains a {@link + com.moparisthebest.poi.hpsf.Property} array which can be retrieved with {@link + com.moparisthebest.poi.hpsf.Section#getProperties}. Since the vast majority of + {@link com.moparisthebest.poi.hpsf.PropertySet}s contains only a single {@link + com.moparisthebest.poi.hpsf.Section}, the convenience method {@link + com.moparisthebest.poi.hpsf.PropertySet#getProperties} returns the properties of a + {@link com.moparisthebest.poi.hpsf.PropertySet}'s {@link + com.moparisthebest.poi.hpsf.Section} (throwing a {@link + com.moparisthebest.poi.hpsf.NoSingleSectionException} if the {@link + com.moparisthebest.poi.hpsf.PropertySet} contains more (or less) than exactly one + {@link com.moparisthebest.poi.hpsf.Section}).
-Each {@link org.apache.poi.hpsf.Property} has an ID, a +
Each {@link com.moparisthebest.poi.hpsf.Property} has an ID, a type, and a value which can be retrieved - with {@link org.apache.poi.hpsf.Property#getID}, {@link - org.apache.poi.hpsf.Property#getType}, and {@link - org.apache.poi.hpsf.Property#getValue}, respectively. The value's class + with {@link com.moparisthebest.poi.hpsf.Property#getID}, {@link + com.moparisthebest.poi.hpsf.Property#getType}, and {@link + com.moparisthebest.poi.hpsf.Property#getValue}, respectively. The value's class depends on the property's type. The current implementation does not yet support all property types and restricts the values' classes to {@link java.lang.String}, {@link java.lang.Integer} and {@link java.util.Date}. A value of a yet unknown type is returned as a byte array containing the value's origin bytes from the property set stream.
-To retrieve the value of a specific {@link org.apache.poi.hpsf.Property}, - use {@link org.apache.poi.hpsf.Section#getProperty} or {@link - org.apache.poi.hpsf.Section#getPropertyIntValue}.
+To retrieve the value of a specific {@link com.moparisthebest.poi.hpsf.Property}, + use {@link com.moparisthebest.poi.hpsf.Section#getProperty} or {@link + com.moparisthebest.poi.hpsf.Section#getPropertyIntValue}.
-The {@link org.apache.poi.hpsf.SummaryInformation} and {@link - org.apache.poi.hpsf.DocumentSummaryInformation} classes provide convenience +
The {@link com.moparisthebest.poi.hpsf.SummaryInformation} and {@link + com.moparisthebest.poi.hpsf.DocumentSummaryInformation} classes provide convenience methods for retrieving well-known properties. For example, an application that wants to retrieve a document's title string just calls {@link - org.apache.poi.hpsf.SummaryInformation#getTitle} instead of going through + com.moparisthebest.poi.hpsf.SummaryInformation#getTitle} instead of going through the hassle of first finding out what the title's property ID is and then using this ID to get the property's value.
Writing properties can be done with the classes - {@link org.apache.poi.hpsf.MutablePropertySet}, {@link - org.apache.poi.hpsf.MutableSection}, and {@link - org.apache.poi.hpsf.MutableProperty}.
+ {@link com.moparisthebest.poi.hpsf.MutablePropertySet}, {@link + com.moparisthebest.poi.hpsf.MutableSection}, and {@link + com.moparisthebest.poi.hpsf.MutableProperty}.Public documentation from Microsoft can be found in the 2003-09-11:
{@link org.apache.poi.hpsf.PropertySetFactory#create(InputStream)} no
+ {@link com.moparisthebest.poi.hpsf.PropertySetFactory#create(InputStream)} no
longer throws an
- {@link org.apache.poi.hpsf.UnexpectedPropertySetTypeException}.
Maps section format IDs to {@link PropertyIDMap}s. It is
diff --git a/src/main/java/com/moparisthebest/poi/hssf/OldExcelFormatException.java b/src/main/java/com/moparisthebest/poi/hssf/OldExcelFormatException.java
index e42e613d8..5eadfe470 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/OldExcelFormatException.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/OldExcelFormatException.java
@@ -14,9 +14,9 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf;
+package com.moparisthebest.poi.hssf;
-import org.apache.poi.OldFileFormatException;
+import com.moparisthebest.poi.OldFileFormatException;
public class OldExcelFormatException extends OldFileFormatException {
public OldExcelFormatException(String s) {
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventmodel/ERFListener.java b/src/main/java/com/moparisthebest/poi/hssf/eventmodel/ERFListener.java
index 91276490b..cb47c9864 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventmodel/ERFListener.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventmodel/ERFListener.java
@@ -15,9 +15,9 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventmodel;
+package com.moparisthebest.poi.hssf.eventmodel;
-import org.apache.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.Record;
/**
* An ERFListener is registered with the EventRecordFactory.
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventmodel/EventRecordFactory.java b/src/main/java/com/moparisthebest/poi/hssf/eventmodel/EventRecordFactory.java
index 519d4bbdb..09d04ad1a 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventmodel/EventRecordFactory.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventmodel/EventRecordFactory.java
@@ -15,12 +15,12 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventmodel;
+package com.moparisthebest.poi.hssf.eventmodel;
import java.io.InputStream;
import java.util.Arrays;
-import org.apache.poi.hssf.record.*;
+import com.moparisthebest.poi.hssf.record.*;
/**
* Event-based record factory. As opposed to RecordFactory
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/EventWorkbookBuilder.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/EventWorkbookBuilder.java
index eb65517ce..07bd92094 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/EventWorkbookBuilder.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/EventWorkbookBuilder.java
@@ -14,20 +14,20 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
import java.util.ArrayList;
import java.util.List;
-import org.apache.poi.hssf.model.HSSFFormulaParser;
-import org.apache.poi.hssf.model.InternalWorkbook;
-import org.apache.poi.hssf.record.BoundSheetRecord;
-import org.apache.poi.hssf.record.EOFRecord;
-import org.apache.poi.hssf.record.ExternSheetRecord;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.record.SSTRecord;
-import org.apache.poi.hssf.record.SupBookRecord;
-import org.apache.poi.hssf.usermodel.HSSFWorkbook;
+import com.moparisthebest.poi.hssf.model.HSSFFormulaParser;
+import com.moparisthebest.poi.hssf.model.InternalWorkbook;
+import com.moparisthebest.poi.hssf.record.BoundSheetRecord;
+import com.moparisthebest.poi.hssf.record.EOFRecord;
+import com.moparisthebest.poi.hssf.record.ExternSheetRecord;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.SSTRecord;
+import com.moparisthebest.poi.hssf.record.SupBookRecord;
+import com.moparisthebest.poi.hssf.usermodel.HSSFWorkbook;
/**
* When working with the EventUserModel, if you want to
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/FormatTrackingHSSFListener.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/FormatTrackingHSSFListener.java
index de9814e3a..31f200420 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/FormatTrackingHSSFListener.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/FormatTrackingHSSFListener.java
@@ -14,7 +14,7 @@
See the License for the specific language governing permissions and
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
import java.text.NumberFormat;
import java.util.ArrayList;
@@ -23,17 +23,17 @@ import java.util.List;
import java.util.Locale;
import java.util.Map;
-import org.apache.poi.hssf.record.CellValueRecordInterface;
-import org.apache.poi.hssf.record.ExtendedFormatRecord;
-import org.apache.poi.hssf.record.FormatRecord;
-import org.apache.poi.hssf.record.FormulaRecord;
-import org.apache.poi.hssf.record.NumberRecord;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.usermodel.HSSFDataFormat;
-import org.apache.poi.hssf.usermodel.HSSFDataFormatter;
-import org.apache.poi.util.LocaleUtil;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
+import com.moparisthebest.poi.hssf.record.CellValueRecordInterface;
+import com.moparisthebest.poi.hssf.record.ExtendedFormatRecord;
+import com.moparisthebest.poi.hssf.record.FormatRecord;
+import com.moparisthebest.poi.hssf.record.FormulaRecord;
+import com.moparisthebest.poi.hssf.record.NumberRecord;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.usermodel.HSSFDataFormat;
+import com.moparisthebest.poi.hssf.usermodel.HSSFDataFormatter;
+import com.moparisthebest.poi.util.LocaleUtil;
+import com.moparisthebest.poi.util.POILogFactory;
+import com.moparisthebest.poi.util.POILogger;
/**
* A proxy HSSFListener that keeps track of the document formatting records, and
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFEventFactory.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFEventFactory.java
index 929ec6cd1..15a118c7e 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFEventFactory.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFEventFactory.java
@@ -15,17 +15,17 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
import java.io.InputStream;
import java.io.IOException;
import java.util.Set;
-import org.apache.poi.hssf.eventusermodel.HSSFUserException;
-import org.apache.poi.hssf.record.*;
-import org.apache.poi.poifs.filesystem.DirectoryNode;
-import org.apache.poi.poifs.filesystem.POIFSFileSystem;
-import static org.apache.poi.hssf.model.InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES;
+import com.moparisthebest.poi.hssf.eventusermodel.HSSFUserException;
+import com.moparisthebest.poi.hssf.record.*;
+import com.moparisthebest.poi.poifs.filesystem.DirectoryNode;
+import com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem;
+import static com.moparisthebest.poi.hssf.model.InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES;
/**
* Low level event based HSSF reader. Pass either a DocumentInputStream to
@@ -127,7 +127,7 @@ public class HSSFEventFactory {
* the method will return just as with This exception is provided as a way for API users to throw
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/MissingRecordAwareHSSFListener.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/MissingRecordAwareHSSFListener.java
index ea9b70d88..4b8cc5471 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/MissingRecordAwareHSSFListener.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/MissingRecordAwareHSSFListener.java
@@ -15,21 +15,21 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
-import org.apache.poi.hssf.eventusermodel.dummyrecord.LastCellOfRowDummyRecord;
-import org.apache.poi.hssf.eventusermodel.dummyrecord.MissingCellDummyRecord;
-import org.apache.poi.hssf.eventusermodel.dummyrecord.MissingRowDummyRecord;
-import org.apache.poi.hssf.record.BOFRecord;
-import org.apache.poi.hssf.record.CellValueRecordInterface;
-import org.apache.poi.hssf.record.MulBlankRecord;
-import org.apache.poi.hssf.record.MulRKRecord;
-import org.apache.poi.hssf.record.NoteRecord;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.record.RecordFactory;
-import org.apache.poi.hssf.record.RowRecord;
-import org.apache.poi.hssf.record.SharedFormulaRecord;
-import org.apache.poi.hssf.record.StringRecord;
+import com.moparisthebest.poi.hssf.eventusermodel.dummyrecord.LastCellOfRowDummyRecord;
+import com.moparisthebest.poi.hssf.eventusermodel.dummyrecord.MissingCellDummyRecord;
+import com.moparisthebest.poi.hssf.eventusermodel.dummyrecord.MissingRowDummyRecord;
+import com.moparisthebest.poi.hssf.record.BOFRecord;
+import com.moparisthebest.poi.hssf.record.CellValueRecordInterface;
+import com.moparisthebest.poi.hssf.record.MulBlankRecord;
+import com.moparisthebest.poi.hssf.record.MulRKRecord;
+import com.moparisthebest.poi.hssf.record.NoteRecord;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.RecordFactory;
+import com.moparisthebest.poi.hssf.record.RowRecord;
+import com.moparisthebest.poi.hssf.record.SharedFormulaRecord;
+import com.moparisthebest.poi.hssf.record.StringRecord;
/**
* A HSSFListener which tracks rows and columns, and will
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/DummyRecordBase.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/DummyRecordBase.java
index ebb0c032e..c6f07d40e 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/DummyRecordBase.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/DummyRecordBase.java
@@ -15,10 +15,10 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel.dummyrecord;
+package com.moparisthebest.poi.hssf.eventusermodel.dummyrecord;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.record.RecordFormatException;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.RecordFormatException;
/**
*/
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/LastCellOfRowDummyRecord.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/LastCellOfRowDummyRecord.java
index bd4afe890..1528c0e94 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/LastCellOfRowDummyRecord.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/LastCellOfRowDummyRecord.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel.dummyrecord;
+package com.moparisthebest.poi.hssf.eventusermodel.dummyrecord;
/**
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingCellDummyRecord.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingCellDummyRecord.java
index 393e21f38..eda67323c 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingCellDummyRecord.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingCellDummyRecord.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel.dummyrecord;
+package com.moparisthebest.poi.hssf.eventusermodel.dummyrecord;
/**
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingRowDummyRecord.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingRowDummyRecord.java
index 4c128bd00..134c4f234 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingRowDummyRecord.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/dummyrecord/MissingRowDummyRecord.java
@@ -15,7 +15,7 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel.dummyrecord;
+package com.moparisthebest.poi.hssf.eventusermodel.dummyrecord;
/**
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/package.html b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/package.html
index 0a3b111a4..81025e4e1 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/package.html
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/package.html
@@ -35,7 +35,7 @@ For overviews, tutorials, examples, guides, and tool documentation, please see:
-@see org.apache.poi.hssf.usermodel
-@see org.apache.poi.hssf.record
+@see com.moparisthebest.poi.hssf.usermodel
+@see com.moparisthebest.poi.hssf.record
abortableProcessEvents
, but no
* user code or HSSFUserException
will be passed back.
*
- * @see org.apache.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
+ * @see com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
* @param req an Instance of HSSFRequest which has your registered listeners
* @param in a DocumentInputStream obtained from POIFS's POIFSFileSystem object
*/
@@ -143,7 +143,7 @@ public class HSSFEventFactory {
/**
* Processes a DocumentInputStream into essentially Record events.
*
- * @see org.apache.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
+ * @see com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
* @param req an Instance of HSSFRequest which has your registered listeners
* @param in a DocumentInputStream obtained from POIFS's POIFSFileSystem object
* @return numeric user-specified result code.
@@ -158,7 +158,7 @@ public class HSSFEventFactory {
/**
* Processes a DocumentInputStream into essentially Record events.
*
- * @see org.apache.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
+ * @see com.moparisthebest.poi.poifs.filesystem.POIFSFileSystem#createDocumentInputStream(String)
* @param req an Instance of HSSFRequest which has your registered listeners
* @param in a DocumentInputStream obtained from POIFS's POIFSFileSystem object
* @return numeric user-specified result code.
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFListener.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFListener.java
index 8932b10cd..5a406648c 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFListener.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFListener.java
@@ -16,17 +16,17 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
-import org.apache.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.Record;
/**
* Interface for use with the HSSFRequest and HSSFEventFactory. Users should create
* a listener supporting this interface and register it with the HSSFRequest (associating
* it with Record SID's).
*
- * @see org.apache.poi.hssf.eventusermodel.HSSFEventFactory
- * @see org.apache.poi.hssf.eventusermodel.HSSFRequest
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFEventFactory
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFRequest
*/
public interface HSSFListener
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/AbortableHSSFListener.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/AbortableHSSFListener.java
index 9000a7476..68d461572 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/AbortableHSSFListener.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/AbortableHSSFListener.java
@@ -16,10 +16,10 @@
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.eventusermodel.HSSFUserException;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.eventusermodel.HSSFUserException;
/**
* Abstract class for use with the HSSFRequest and HSSFEventFactory, which
@@ -30,9 +30,9 @@ import org.apache.poi.hssf.eventusermodel.HSSFUserException;
* This should then be registered with the HSSFRequest (associating
* it with Record SID's) as usual.
*
* @see org.apache.poi.hssf.eventusermodel.HSSFEventFactory
* @see org.apache.poi.hssf.eventusermodel.HSSFRequest
* @see org.apache.poi.hssf.eventusermodel.HSSFUserException
*/
public abstract class AbortableHSSFListener implements HSSFListener
@@ -30,9 +30,9 @@ import org.apache.poi.hssf.eventusermodel.HSSFUserException;
* it with Record SID's) as usual.
*
- * @see org.apache.poi.hssf.eventusermodel.HSSFEventFactory
- * @see org.apache.poi.hssf.eventusermodel.HSSFRequest
- * @see org.apache.poi.hssf.eventusermodel.HSSFUserException
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFEventFactory
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFRequest
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFUserException
*/
public abstract class AbortableHSSFListener implements HSSFListener
diff --git a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFRequest.java b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFRequest.java
index 64c11aa65..d64e1e03c 100644
--- a/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFRequest.java
+++ b/src/main/java/com/moparisthebest/poi/hssf/eventusermodel/HSSFRequest.java
@@ -15,23 +15,23 @@
limitations under the License.
==================================================================== */
-package org.apache.poi.hssf.eventusermodel;
+package com.moparisthebest.poi.hssf.eventusermodel;
import java.util.HashMap;
import java.util.List;
import java.util.ArrayList;
import java.util.Map;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.record.RecordFactory;
+import com.moparisthebest.poi.hssf.record.Record;
+import com.moparisthebest.poi.hssf.record.RecordFactory;
/**
* An HSSFRequest object should be constructed registering an instance or multiple
* instances of HSSFListener with each Record.sid you wish to listen for.
*
* @see org.apache.poi.hssf.eventusermodel.HSSFEventFactory
* @see org.apache.poi.hssf.eventusermodel.HSSFListener
* @see org.apache.poi.hssf.eventusermodel.HSSFUserException
*/
public class HSSFRequest {
private final Map
@@ -15,23 +15,23 @@
* instances of HSSFListener with each Record.sid you wish to listen for.
*
- * @see org.apache.poi.hssf.eventusermodel.HSSFEventFactory
- * @see org.apache.poi.hssf.eventusermodel.HSSFListener
- * @see org.apache.poi.hssf.eventusermodel.HSSFUserException
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFEventFactory
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFListener
+ * @see com.moparisthebest.poi.hssf.eventusermodel.HSSFUserException
*/
public class HSSFRequest {